@@ -62,9 +62,7 @@ class MaskingFilter(LoggingFilter):
 
     def mask(self, msg: str) -> str:
         if not isinstance(msg, str):
-            logger.debug(  # type: ignore[unreachable]
-                "cannot mask object of type %s", type(msg)
-            )
+            logger.debug("cannot mask object of type %s", type(msg))
             return msg
         for mask, values in self._redact_patterns.items():
             repl_string = (
