@@ -203,6 +203,15 @@ class Version:
     def as_tag(self) -> str:
         return self.tag_format.format(version=str(self))
 
+    def as_major_tag(self) -> str:
+        return self.tag_format.format(version=f"{self.major}")
+
+    def as_minor_tag(self) -> str:
+        return self.tag_format.format(version=f"{self.major}.{self.minor}")
+
+    def as_patch_tag(self) -> str:
+        return self.tag_format.format(version=f"{self.major}.{self.minor}.{self.patch}")
+
     def as_semver_tag(self) -> str:
         return f"v{self!s}"
 
