@@ -96,8 +96,10 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
     monorepo_pkg2_changelog_rst_file: Path,
     monorepo_pkg1_name: str,
     monorepo_pkg2_name: str,
-    monorepo_pkg1_dir: Path,
-    monorepo_pkg2_dir: Path,
+    monorepo_pkg1_dir: str,
+    monorepo_pkg2_dir: str,
+    monorepo_pkg1_docs_dir: str,
+    monorepo_pkg2_docs_dir: str,
     monorepo_pkg1_version_py_file: Path,
     monorepo_pkg2_version_py_file: Path,
     monorepo_pkg1_pyproject_toml_file: Path,
@@ -117,7 +119,8 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
     * chore(release): pkg1@1.1.0 [skip ci] (tag: pkg1-v1.1.0, branch: main, HEAD -> main)
     * feat(pkg1): file modified outside of pkg 1, identified by scope (#5)
     |
-    | * feat(pkg1): file modified outside of pkg 1, identified by scope (branch: pkg1/feat/pr-4)
+    | * docs: pkg1 docs modified outside of pkg 1, identified by path filter (branch: pkg1/feat/pr-4)
+    | * feat(pkg1): file modified outside of pkg 1, identified by scope
     |/
     * chore(release): pkg2@1.1.1 [skip ci] (tag: pkg2-v1.1.1)
     * fix(pkg2-cli): file modified outside of pkg 2, identified by scope (#4)
@@ -207,21 +210,23 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
         if commit_type != "conventional":
             raise ValueError(f"Unsupported commit type: {commit_type}")
 
+        pkg1_path_filters = (".", f"../../{monorepo_pkg1_docs_dir}")
         pkg1_commit_parser = ConventionalCommitMonorepoParser(
             options=ConventionalCommitMonorepoParserOptions(
                 parse_squash_commits=True,
                 ignore_merge_commits=ignore_merge_commits,
                 scope_prefix=f"{monorepo_pkg1_name}-?",
-                path_filters=(".",),
+                path_filters=pkg1_path_filters,
             )
         )
 
+        pkg2_path_filters = (".", f"../../{monorepo_pkg2_docs_dir}")
         pkg2_commit_parser = ConventionalCommitMonorepoParser(
             options=ConventionalCommitMonorepoParserOptions(
                 parse_squash_commits=pkg1_commit_parser.options.parse_squash_commits,
                 ignore_merge_commits=pkg1_commit_parser.options.ignore_merge_commits,
                 scope_prefix=f"{monorepo_pkg2_name}-?",
-                path_filters=(".",),
+                path_filters=pkg2_path_filters,
             )
         )
 
@@ -277,7 +282,7 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
                                         )
                                     ),
                                     "tool.semantic_release.commit_parser_options.scope_prefix": pkg1_commit_parser.options.scope_prefix,
-                                    "tool.semantic_release.commit_parser_options.path_filters": pkg1_commit_parser.options.path_filters,
+                                    "tool.semantic_release.commit_parser_options.path_filters": pkg1_path_filters,
                                     **(extra_configs or {}),
                                 },
                             },
@@ -301,7 +306,7 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
                                         )
                                     ),
                                     "tool.semantic_release.commit_parser_options.scope_prefix": pkg2_commit_parser.options.scope_prefix,
-                                    "tool.semantic_release.commit_parser_options.path_filters": pkg2_commit_parser.options.path_filters,
+                                    "tool.semantic_release.commit_parser_options.path_filters": pkg2_path_filters,
                                     **(extra_configs or {}),
                                 },
                             },
@@ -774,7 +779,15 @@ def get_repo_definition_4_github_flow_monorepo_w_default_release_channel(
                 "emoji": ":sparkles: (pkg1) file modified outside of pkg 1, identified by scope",
                 "scipy": "ENH:pkg1: file modified outside of pkg 1, identified by scope",
                 "datetime": next(commit_timestamp_gen),
-            }
+            },
+            {
+                "cid": "pkg1-docs-2-squashed",
+                "conventional": "docs: pkg1 docs modified outside of pkg 1, identified by path filter",
+                "emoji": ":book: pkg1 docs modified outside of pkg 1, identified by path filter",
+                "scipy": "DOC: pkg1 docs modified outside of pkg 1, identified by path filter",
+                "datetime": next(commit_timestamp_gen),
+                "file_to_change": f"{monorepo_pkg1_docs_dir}/index.rst",
+            },
         ]
 
         repo_construction_steps.extend(
