@@ -3,11 +3,12 @@ from __future__ import annotations
 from datetime import timedelta
 from itertools import count
 from pathlib import Path
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, cast
 
 import pytest
 
 from semantic_release.cli.config import ChangelogOutputFormat
+from semantic_release.version.version import Version
 
 import tests.conftest
 import tests.const
@@ -20,7 +21,15 @@ from tests.const import (
 )
 
 if TYPE_CHECKING:
-    from typing import Sequence
+    from typing import Any, Sequence
+
+    from semantic_release.commit_parser._base import CommitParser, ParserOptions
+    from semantic_release.commit_parser.conventional.parser import (
+        ConventionalCommitParser,
+    )
+    from semantic_release.commit_parser.emoji import EmojiCommitParser
+    from semantic_release.commit_parser.scipy import ScipyCommitParser
+    from semantic_release.commit_parser.token import ParseResult
 
     from tests.conftest import (
         GetCachedRepoDataFn,
@@ -79,34 +88,50 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
     changelog_md_file: Path,
     changelog_rst_file: Path,
     stable_now_date: GetStableDateNowFn,
+    default_conventional_parser: ConventionalCommitParser,
+    default_emoji_parser: EmojiCommitParser,
+    default_scipy_parser: ScipyCommitParser,
+    default_tag_format_str: str,
 ) -> GetRepoDefinitionFn:
     """
     Builds a repository with trunk-only committing (no-branching) strategy with
     only official releases with latest and previous version support.
     """
+    parser_classes: dict[CommitConvention, CommitParser[Any, Any]] = {
+        "conventional": default_conventional_parser,
+        "emoji": default_emoji_parser,
+        "scipy": default_scipy_parser,
+    }
 
-    def _get_repo_from_defintion(
+    def _get_repo_from_definition(
         commit_type: CommitConvention,
         hvcs_client_name: str = "github",
         hvcs_domain: str = EXAMPLE_HVCS_DOMAIN,
         tag_format_str: str | None = None,
         extra_configs: dict[str, TomlSerializableTypes] | None = None,
-        mask_initial_release: bool = False,
+        mask_initial_release: bool = True,
+        ignore_merge_commits: bool = True,
     ) -> Sequence[RepoActions]:
         stable_now_datetime = stable_now_date()
         commit_timestamp_gen = (
             (stable_now_datetime + timedelta(seconds=i)).isoformat(timespec="seconds")
             for i in count(step=1)
         )
+        commit_parser = cast(
+            "CommitParser[ParseResult, ParserOptions]",
+            parser_classes[commit_type],
+        )
 
-        changelog_file_definitons: Sequence[RepoActionWriteChangelogsDestFile] = [
+        changelog_file_definitions: Sequence[RepoActionWriteChangelogsDestFile] = [
             {
                 "path": changelog_md_file,
                 "format": ChangelogOutputFormat.MARKDOWN,
+                "mask_initial_release": mask_initial_release,
             },
             {
                 "path": changelog_rst_file,
                 "format": ChangelogOutputFormat.RESTRUCTURED_TEXT,
+                "mask_initial_release": mask_initial_release,
             },
         ]
 
@@ -119,7 +144,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                     "commit_type": commit_type,
                     "hvcs_client_name": hvcs_client_name,
                     "hvcs_domain": hvcs_domain,
-                    "tag_format_str": tag_format_str,
+                    "tag_format_str": tag_format_str or default_tag_format_str,
                     "mask_initial_release": mask_initial_release,
                     "extra_configs": {
                         # Set the default release branch
@@ -131,6 +156,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                             "match": r"^v1\.x$",
                             "prerelease": False,
                         },
+                        "tool.semantic_release.commit_parser_options.ignore_merge_commits": ignore_merge_commits,
                         "tool.semantic_release.allow_zero_version": False,
                         **(extra_configs or {}),
                     },
@@ -139,7 +165,9 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make initial release
-        new_version = "1.0.0"
+        new_version = Version.parse(
+            "1.0.0", tag_format=(tag_format_str or default_tag_format_str)
+        )
 
         repo_construction_steps.extend(
             [
@@ -149,6 +177,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c1_initial := "c1-initial_commit"),
                                     "conventional": INITIAL_COMMIT_MESSAGE,
                                     "emoji": INITIAL_COMMIT_MESSAGE,
                                     "scipy": INITIAL_COMMIT_MESSAGE,
@@ -158,6 +187,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                     ),
                                 },
                                 {
+                                    "cid": (cid_c2_feat := "c2-feat"),
                                     "conventional": "feat: add new feature",
                                     "emoji": ":sparkles: add new feature",
                                     "scipy": "ENH: add new feature",
@@ -166,20 +196,23 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c1_initial, cid_c2_feat],
                                 },
                             },
                         ],
@@ -189,7 +222,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make a fix and officially release it
-        new_version = "1.0.1"
+        new_version = Version.parse("1.0.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -198,6 +231,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c3_fix := "c3-fix"),
                                     "conventional": "fix: correct some text",
                                     "emoji": ":bug: correct some text",
                                     "scipy": "MAINT: correct some text",
@@ -206,20 +240,23 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c3_fix],
                                 },
                             },
                         ],
@@ -229,7 +266,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # Make a breaking change and officially release it
-        new_version = "2.0.0"
+        new_version = Version.parse("2.0.0", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -251,6 +288,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c4_bfeat := "c4-breaking-feat1"),
                                     "conventional": str.join(
                                         "\n\n",
                                         [
@@ -269,7 +307,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                         "\n\n",
                                         [
                                             "API: add revolutionary feature",
-                                            "BREAKING CHANGE: this is a breaking change",
+                                            "This is a breaking change",
                                         ],
                                     ),
                                     "datetime": next(commit_timestamp_gen),
@@ -277,20 +315,23 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
                                 "action": RepoActionStep.WRITE_CHANGELOGS,
                                 "details": {
                                     "new_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c4_bfeat],
                                 },
                             },
                         ],
@@ -301,7 +342,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
 
         # Attempt to fix a critical bug in the previous version and release it as a prerelease version
         # This is based on https://github.com/python-semantic-release/python-semantic-release/issues/861
-        new_version = "1.0.2-hotfix.1"
+        new_version = Version.parse("1.0.2-hotfix.1", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -314,21 +355,24 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
-                                    "conventional": "fix: correct critical bug",
-                                    "emoji": ":bug: correct critical bug",
-                                    "scipy": "MAINT: correct critical bug",
+                                    "cid": (cid_c5_v1_fix := "c5-fix2"),
+                                    "conventional": "fix: correct critical bug\n\nResolves: #123\n",
+                                    "emoji": ":bug: correct critical bug\n\nResolves: #123\n",
+                                    "scipy": "MAINT: correct critical bug\n\nResolves: #123\n",
                                     "datetime": next(commit_timestamp_gen),
                                     "include_in_changelog": True,
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -336,7 +380,8 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c5_v1_fix],
                                 },
                             },
                         ],
@@ -346,7 +391,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # The Hotfix didn't work, so correct it and try again
-        new_version = "1.0.2-hotfix.2"
+        new_version = Version.parse("1.0.2-hotfix.2", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 {
@@ -355,6 +400,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                         "commits": convert_commit_specs_to_commit_defs(
                             [
                                 {
+                                    "cid": (cid_c6_v1_fix := "c6-fix3"),
                                     "conventional": "fix: resolve critical bug",
                                     "emoji": ":bug: resolve critical bug",
                                     "scipy": "MAINT: resolve critical bug",
@@ -363,13 +409,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 },
                             ],
                             commit_type,
+                            parser=commit_parser,
                         ),
                     },
                 },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -377,7 +425,8 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [cid_c6_v1_fix],
                                 },
                             },
                         ],
@@ -387,7 +436,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
         )
 
         # It finally was resolved so release it officially
-        new_version = "1.0.2"
+        new_version = Version.parse("1.0.2", tag_format=new_version.tag_format)
         repo_construction_steps.extend(
             [
                 # {
@@ -396,6 +445,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                 #         "commits": convert_commit_specs_to_commit_defs(
                 #             [
                 #                 {
+                #                     "cid": (cid_c7_v1_docs := "c7-docs"),
                 #                     "conventional": "docs: update documentation regarding critical bug",
                 #                     "emoji": ":books: update documentation regarding critical bug",
                 #                     "scipy": "DOC: update documentation regarding critical bug",
@@ -404,13 +454,15 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                 #                 },
                 #             ],
                 #             commit_type,
+                #             parser=commit_parser,
                 #         ),
                 #     },
                 # },
                 {
                     "action": RepoActionStep.RELEASE,
                     "details": {
-                        "version": new_version,
+                        "version": str(new_version),
+                        "tag_format": new_version.tag_format,
                         "datetime": next(commit_timestamp_gen),
                         "pre_actions": [
                             {
@@ -418,7 +470,12 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
                                 "details": {
                                     "new_version": new_version,
                                     "max_version": new_version,
-                                    "dest_files": changelog_file_definitons,
+                                    "dest_files": changelog_file_definitions,
+                                    "commit_ids": [
+                                        cid_c5_v1_fix,
+                                        cid_c6_v1_fix,
+                                        # cid_c7_v1_docs,
+                                    ],
                                 },
                             },
                         ],
@@ -441,7 +498,7 @@ def get_repo_definition_4_trunk_only_repo_w_dual_version_spt_w_prereleases(
 
         return repo_construction_steps
 
-    return _get_repo_from_defintion
+    return _get_repo_from_definition
 
 
 @pytest.fixture(scope="session")
